summaryrefslogtreecommitdiffstats
path: root/Http
diff options
context:
space:
mode:
authorFabien Potencier <fabien.potencier@gmail.com>2014-04-15 07:44:12 +0200
committerFabien Potencier <fabien.potencier@gmail.com>2014-04-15 07:44:12 +0200
commit3c065747901d8ba53056cb769cb1ef986e39c1d0 (patch)
tree3540ae13ca5bf1b473c9ba7bcc17a3221a4ba981 /Http
parente5960cb3c8dc2c885c4fe784e957f8d1286f3fc7 (diff)
parentc9dff33575d2eb04e34c31167f5fba8bf3f355d6 (diff)
downloadsymfony-security-3c065747901d8ba53056cb769cb1ef986e39c1d0.zip
symfony-security-3c065747901d8ba53056cb769cb1ef986e39c1d0.tar.gz
symfony-security-3c065747901d8ba53056cb769cb1ef986e39c1d0.tar.bz2
minor #10701 Made types used by Symfony compatible with the ones of Hack (fabpot)
This PR was merged into the 2.3 branch. Discussion ---------- Made types used by Symfony compatible with the ones of Hack | Q | A | ------------- | --- | Bug fix? | no | New feature? | no | BC breaks? | no | Deprecations? | no | Tests pass? | yes | Fixed tickets | n/a | License | MIT | Doc PR | n/a PHP supports several ways to express types: like Boolean/bool or integer/int. Hack only supports one of them, so this PR proposes to use the Hack type to make Symfony a bit more "compatible" with Hack (gradual upgrade ;)). Commits ------- 3c9c10f made phpdoc types consistent with those defined in Hack 0555b7f made types consistent with those defined in Hack
Diffstat (limited to 'Http')
-rw-r--r--Http/EntryPoint/FormAuthenticationEntryPoint.php4
-rw-r--r--Http/HttpUtils.php2
-rw-r--r--Http/RememberMe/TokenBasedRememberMeServices.php4
3 files changed, 5 insertions, 5 deletions
diff --git a/Http/HttpUtils.php b/Http/HttpUtils.php
index 0c8b21b..a7b0226 100644
--- a/Http/HttpUtils.php
+++ b/Http/HttpUtils.php
@@ -53,7 +53,7 @@ class HttpUtils
*
* @param Request $request A Request instance
* @param string $path A path (an absolute path (/foo), an absolute URL (http://...), or a route name (foo))
- * @param integer $status The status code
+ * @param int $status The status code
*
* @return RedirectResponse A RedirectResponse instance
*/
diff --git a/Http/RememberMe/TokenBasedRememberMeServices.php b/Http/RememberMe/TokenBasedRememberMeServices.php
index df0ea1b..64d41be 100644
--- a/Http/RememberMe/TokenBasedRememberMeServices.php
+++ b/Http/RememberMe/TokenBasedRememberMeServices.php
@@ -116,7 +116,7 @@ class TokenBasedRememberMeServices extends AbstractRememberMeServices
*
* @param string $class
* @param string $username The username
- * @param integer $expires The Unix timestamp when the cookie expires
+ * @param int $expires The Unix timestamp when the cookie expires
* @param string $password The encoded password
*
* @throws \RuntimeException if username contains invalid chars
@@ -138,7 +138,7 @@ class TokenBasedRememberMeServices extends AbstractRememberMeServices
*
* @param string $class
* @param string $username The username
- * @param integer $expires The Unix timestamp when the cookie expires
+ * @param int $expires The Unix timestamp when the cookie expires
* @param string $password The encoded password
*
* @throws \RuntimeException when the private key is empty
diff --git a/Http/EntryPoint/FormAuthenticationEntryPoint.php b/Http/EntryPoint/FormAuthenticationEntryPoint.php
index b78f0a9..c734db0 100644
--- a/Http/EntryPoint/FormAuthenticationEntryPoint.php
+++ b/Http/EntryPoint/FormAuthenticationEntryPoint.php
@@ -34,14 +34,14 @@ class FormAuthenticationEntryPoint implements AuthenticationEntryPointInterface
* @param HttpKernelInterface $kernel
* @param HttpUtils $httpUtils An HttpUtils instance
* @param string $loginPath The path to the login form
* @param Boolean $useForward Whether to forward or redirect to the login form
*/
public function __construct(HttpKernelInterface $kernel, HttpUtils $httpUtils, $loginPath, $useForward = false)
{
$this->httpKernel = $kernel;
$this->httpUtils = $httpUtils;
$this->loginPath = $loginPath;
- $this->useForward = (Boolean) $useForward;
+ $this->useForward = (bool) $useForward;
}
/**
@@ -34,14 +34,14 @@ class FormAuthenticationEntryPoint implements AuthenticationEntryPointInterface
* @param HttpUtils $httpUtils An HttpUtils instance
* @param string $loginPath The path to the login form
- * @param Boolean $useForward Whether to forward or redirect to the login form
+ * @param bool $useForward Whether to forward or redirect to the login form
*/
public function __construct(HttpKernelInterface $kernel, HttpUtils $httpUtils, $loginPath, $useForward = false)